@@ -1,5 +1,3 @@
-# Copyright (C) 2008-2010, Sebastian Riedel.
-
 package Mojolicious::Command::Generate::LiteApp;
 
 use strict;
@@ -39,10 +37,10 @@ get '/' => 'index';
 
 get '/:groovy' => sub {
     my $self = shift;
-    $self->render_text($self->param('groovy'), layout => 'funky');
+    $self->render(text => $self->param('groovy'), layout => 'funky');
 };
 
-shagadelic;
+app->start;
 <%%= '__DATA__' %%>
 
 <%%= '@@ index.html.ep' %%>
